@@ -121,7 +121,7 @@ def print(obj = "", end=b"\n"):
 
 
 def traceback(tag_name: str = "code", class_name: str = "traceback", style: str = "", limit=None, chain=True):
-    return "<{tag} class='{}' style='{}'></{tag}>".format(
+    return "<{tag} class='{}' style='{}'>{}</{tag}>".format(
         class_name,
         style,
         escape(_traceback.format_exc(limit, chain)).replace("\n", "<br>\n"),
@@ -174,14 +174,14 @@ def execute(method, enable_tb: bool = True, traceback_kwargs: dict = None):
             except:
                 __headers.update(default_content_type)
                 log(_traceback.format_exc(limit, chain))
-                try:
-                    set_status(500)
-                except:
-                    log(_traceback.format_exc())
                 if enable_tb:
                     tb = traceback(**(traceback_kwargs or {}))
                 else:
                     tb = "<h1>500 Internal Server Error</h1><br/><p>HTML stack trace is disabled.<br/>Check traceback log.</p>"
+                try:
+                    set_status(500)
+                except:
+                    log(_traceback.format_exc())
                 __response["content"] = tb.encode()
             try:
                 _generate_response()
